import { Component } from '@angular/core';

@Component({
    selector: 'my-app',
    template: '<h1>Ignite UI Sample</h1><ig-pivot-grid [widgetId]="gridId" [options]="pivotOptions"></ig-pivot-grid><div id="chart1" class="ig-chart-root"></div>'
})
export class AppComponent { 
    private data: Array<any>;
    private ds: any;
    private pivotOptions: IgPivotGrid;
    private gridId: string = "pivotGrid1";
    private pivotGridRenderedProxy: PivotGridRenderedEvent;

    constructor() {
        this.data = [
            { "ProductCategory": "Clothing", "UnitPrice": 12.814, "SellerName": "Stanley Brooker", "Country": "Uruguay", "City": "Montevideo", "Date": "01/01/2007", "UnitsSold": 282 },
            { "ProductCategory": "Clothing", "UnitPrice": 49.579, "SellerName": "Elisa Longbottom", "Country": "UK", "City": "Cambrige", "Date": "01/05/2007", "UnitsSold": 296 }];
            this.ds = new jQuery.ig.OlapFlatDataSource({
                    dataSource: this.data,
                    metadata: {
                        cube: {
                            name: "Sales",
                            caption: "Sales",
                            measuresDimension: {
                                caption: "Measures",
                                measures: [
                                { caption: "Units Sold", name: "UnitsSold", aggregator: jQuery.ig.OlapUtilities.prototype.sumAggregator('UnitsSold') },
                                { caption: "Unit Price", name: "UnitPrice", aggregator: jQuery.ig.OlapUtilities.prototype.sumAggregator('UnitPrice', 2) }]
                            },
                            dimensions: [
                                {
                                    caption: "Date", name: "Date", hierarchies: [
                                        jQuery.ig.OlapUtilities.prototype.getDateHierarchy(
                                            "Date", ["year", "quarter", "month", "date"], "Dates", "Date",
                                            ["Year", "Quarter", "Month", "Day"], "All Periods")]
                                },
                                {
                                    caption: "Location", name: "Location", hierarchies: [{
                                        caption: "Location", name: "Location", levels: [
                                        { name: "AllLocations", levelCaption: "All Locations", memberProvider: function (item) { return "All Locations"; } },
                                        { name: "Country", levelCaption: "Country", memberProvider: function (item) { return item.Country; } },
                                        { name: "City", levelCaption: "City", memberProvider: function (item) { return item.City; } }]
                                    }]
                                },
                                {
                                    caption: "Product", name: "Product", hierarchies: [{
                                        caption: "Product", name: "Product", levels: [
                                        { name: "AllProducts", levelCaption: "All Products", memberProvider: function (item) { return "All Products"; } },
                                        { name: "ProductCategory", levelCaption: "Category", memberProvider: function (item) { return item.ProductCategory; } }]
                                    }]
                                },
                                {
                                    caption: "Seller", name: "Seller", hierarchies: [{
                                        caption: "Seller", name: "Seller", levels: [
                                        { name: "AllSellers", levelCaption: "All Sellers", memberProvider: function (item) { return "All Sellers"; } },
                                        { name: "SellerName", levelCaption: "Seller", memberProvider: function (item) { return item.SellerName; } }]
                                    }]
                                }
                            ]
                        }
                    },
                    rows: "[Date].[Dates]",
                    measures: "[Measures].[UnitsSold],[Measures].[UnitPrice]"
                });
            this.pivotGridRenderedProxy = jQuery.proxy(this.pivotGridRendered, this); 
            this.pivotOptions = {
                dataSource: this.ds,
                pivotGridRendered: this.pivotGridRenderedProxy,
                hideFiltersDropArea: true,
                disableColumnsDropArea: true,
                disableRowsDropArea: true,
                disableMeasuresDropArea: true
            }
    }
    pivotGridRendered () {
        this.updateChart(jQuery("#pivotGrid1").data("igPivotGrid")._tableView, true);
    }
    hasValue (value) {
        return value !== undefined && value !== null && value.count() > 0;
    }
    getCellData (rowIndex, columnIndex, columnCount, cells): Number {
        var cellOrdinal = (rowIndex * columnCount) + columnIndex;
        if (!this.hasValue(cells)) {
            return 0;
        }
        for (var index = 0; index < cells.count() ; index++) {
            var cell = cells.item(index);
            if (cell.cellOrdinal() == cellOrdinal) {
                return new Number(cell.value());
            }
        }
        return 0;
    }
    updateChart(tableView, transpose) {
        var columnHeaders,
            rowHeaders,
            cells = tableView.resultCells(),
            dataArray = [],
            series = [],
            rowHeaderIndex,
            columnHeaderIndex,
            ds,
            headerCell,
            columnCount,
            rowCount,
            data;

        if (transpose) {
            columnHeaders = tableView.rowHeaders(),
                rowHeaders = tableView.columnHeaders()
        }
        else {
            columnHeaders = tableView.columnHeaders(),
                rowHeaders = tableView.rowHeaders()
        }

        if (!this.hasValue(cells) && !this.hasValue(rowHeaders) && !this.hasValue(columnHeaders)) {
            jQuery("#chart1").igDataChart("destroy");
            return;
        }

        if (!this.hasValue(rowHeaders)) {
            rowHeaders = [{ caption: function () { return ""; } }];
        }

        if (!this.hasValue(columnHeaders)) {
            columnHeaders = [{ caption: function () { return ""; } }];
        }

        for (rowHeaderIndex = 0; rowHeaderIndex < rowHeaders.count() ; rowHeaderIndex++) {
            headerCell = rowHeaders.item(rowHeaderIndex);
            columnCount = columnHeaders.count();
            rowCount = rowHeaders.count();
            data = { caption: headerCell.caption() };
            var value;
            for (columnHeaderIndex = 0; columnHeaderIndex < columnCount; columnHeaderIndex++) {
                if (transpose) {
                    value = this.getCellData(columnHeaderIndex, rowHeaderIndex, rowCount, cells);
                }
                else {
                    value = this.getCellData(rowHeaderIndex, columnHeaderIndex, columnCount, cells);
                }
                data["col" + columnHeaderIndex] = value;
            }

            dataArray[rowHeaderIndex] = data;
        };

        for (columnHeaderIndex = 0; columnHeaderIndex < columnHeaders.count() ; columnHeaderIndex++) {
            series[columnHeaderIndex] = {
                name: "series" + columnHeaderIndex,
                title: columnHeaders.item(columnHeaderIndex).caption(),
                type: "column",
                xAxis: "xAxis",
                yAxis: "yAxis",
                valueMemberPath: "col" + columnHeaderIndex
            };
        };

        ds = new jQuery.ig.DataSource({ dataSource: dataArray });

        if (jQuery("#chart1").data("igDataChart")) {
            jQuery("#chart1").igDataChart("destroy");
        }
        jQuery("#chart1").igDataChart({
            width: "700px",
            height: "500px",
            dataSource: ds,
            series: series,
            //legend: { element: "olapChartLegend" },
            axes: [{
                name: "xAxis",
                type: "categoryX",
                label: "caption"
            },
            {
                name: "yAxis",
                type: "numericY"
            }],
            horizontalZoomable: true,
            verticalZoomable: true,
            windowResponse: "immediate"
        });
    };
}
}
